NIP-62
======

Request to Vanish
-----------------

`draft` `optional`

This NIP offers a Nostr-native way to request a complete reset of a key's fingerprint on the web. This procedure is legally binding in some jurisdictions, and thus, supporters of this NIP should truly delete events from their database. 

## Request to Vanish from Relay

Kind `62` requests a specific relay to delete everything, including [NIP-09](09.md) Deletion Events, from the `.pubkey` until its `.created_at`. 

```jsonc
{
  "kind": 62,
  "pubkey": <32-byte hex-encoded public key of the event creator>,
  "tags": [
    ["relay", "<relay url>"]
  ],
  "content": "<reason or note>",
  //...other fields
}
```

The tag list MUST include at least one `relay` value. 

Content MAY include a reason or a legal notice to the relay operator. 

Relays MUST fully delete any events from the `.pubkey` if their service URL is tagged in the event. 

Relays SHOULD delete all [NIP-59](59.md) Gift Wraps that p-tagged the `.pubkey` if their service URL is tagged in the event, deleting all DMs to the pubkey.

Relays MUST ensure the deleted events cannot be re-broadcasted into the relay. 

Relays MAY store the signed request to vanish for bookkeeping.

Paid relays or relays that restrict who can post MUST also follow the request to vanish regardless of the user's status. 

Publishing a deletion request event (Kind `5`) against a request to vanish has no effect. Clients and relays are not obliged to support "unrequest vanish" functionality.

Clients SHOULD send this event to the target relays only. 

## Global Request to Vanish

To request ALL relays to delete everything, the event MUST include a `relay` tag with the value `ALL_RELAYS` in uppercase. 

```jsonc
{
  "kind": 62,
  "pubkey": <32-byte hex-encoded public key of the event creator>,
  "tags": [
    ["relay", "ALL_RELAYS"]
  ],
  "content": "<reason>",
  //...other fields
}
```

Clients SHOULD broadcast this event to as many relays as possible. 
